Getting Data From Database
===========================

CLEASE retrieves data from ASE databases, via the generic *DataManager* class.
For convenience, concrete implementations of the *DataManager* is provided for
the most common applications.

.. automodule:: clease.data_manager
    :members:
